@@ -9,7 +9,9 @@
 
 /* a 'safe' version of strdup */
 
-extern char *strdup(const char *s);
+#include <string.h>
+#include <stdlib.h>
+
 #define  x_strdup(s)  ( (s) ? strdup(s):NULL )
 
 /* Good policy to strike out passwords with some characters not just
@@ -61,7 +63,6 @@ do {                                              \
 #include <stdio.h>
 #include <sys/types.h>
 #include <stdarg.h>
-#include <stdlib.h>
 #include <errno.h>
 
 /*
