@@ -1,7 +1,17 @@
 /*
- * $Id: pam_malloc.c,v 1.2 1996/12/01 03:14:13 morgan Exp $
+ * $Id: pam_malloc.c,v 1.1.1.1 2000/06/20 22:11:18 agmorgan Exp $
  *
  * $Log: pam_malloc.c,v $
+ * Revision 1.1.1.1  2000/06/20 22:11:18  agmorgan
+ * Imported 0.72 Linux-PAM sources
+ *
+ * Revision 1.2  1998/12/27 04:34:23  morgan
+ * reverting logging functions within libpam.  Gone are the externally
+ * advertised API replaced by a more simple (libpam internal) one.
+ *
+ * Revision 1.1.1.1  1998/07/12 05:17:15  morgan
+ * Linux PAM sources pre-0.66
+ *
  * Revision 1.2  1996/12/01 03:14:13  morgan
  * use _pam_macros.h
  *
@@ -52,7 +62,7 @@
  * default debugging level
  */
 
-int pam_malloc_flags = PAM_MALLOC_DEFAULT;
+int pam_malloc_flags = PAM_MALLOC_ALL;
 int pam_malloc_delay_length = 4;
 
 #define on(x) ((pam_malloc_flags&(x))==(x))
