@@ -1,5 +1,5 @@
 /*
- * $Id: pam_client.h,v 1.2 1999/10/09 05:04:05 morgan Exp $
+ * $Id: pam_client.h,v 1.3 2000/11/19 23:54:03 agmorgan Exp $
  *
  * Copyright (c) 1999 Andrew G. Morgan <morgan@linux.kernel.org>
  *
@@ -90,7 +90,7 @@ char **pamc_list_agents(pamc_handle_t pch);
 #define __PAM_BP_OCTET(x,y)  (*((y) + (__u8 *)(x)))
 
 #define PAM_BP_MIN_SIZE       (sizeof(__u32) + sizeof(__u8))
-#define PAM_PB_MAX_LENGTH     0x8000                   /* an advisory limit */
+#define PAM_BP_MAX_LENGTH     0x20000                   /* an advisory limit */
 #define PAM_BP_CONTROL(x)     (__PAM_BP_OCTET(x,4))
 #define PAM_BP_SIZE(x)        ((__PAM_BP_OCTET(x,0)<<24)+      \
 			       (__PAM_BP_OCTET(x,1)<<16)+      \
@@ -130,9 +130,10 @@ do {                                                                       \
     }                                                                      \
 } while (0)
 
-#define PAM_BP_FILL(prompt, offset, length, data)                          \
+#define PAM_BP_FILL(prmpt, offset, length, data)                           \
 do {                                                                       \
     int bp_length;                                                         \
+    __u8 *prompt = (__u8 *) (prmpt);                                       \
     bp_length = PAM_BP_LENGTH(prompt);                                     \
     if (bp_length < ((length)+(offset))) {                                 \
 	PAM_BP_ASSERT("attempt to write over end of prompt");              \
@@ -140,9 +141,10 @@ do {                                                                       \
     memcpy((offset) + PAM_BP_DATA(prompt), (data), (length));              \
 } while (0)
 
-#define PAM_BP_EXTRACT(prompt, offset, length, data)                       \
+#define PAM_BP_EXTRACT(prmpt, offset, length, data)                        \
 do {                                                                       \
     int bp_length;                                                         \
+    __u8 *prompt = (__u8 *) (prmpt);                                       \
     bp_length = PAM_BP_LENGTH(prompt);                                     \
     if (((offset) < 0) || bp_length < ((length)+(offset))                  \
 	|| (length) < 0) {                                                 \
