@@ -1,5 +1,5 @@
 /*
- * $Id: pwdb_chkpwd.c,v 1.3 1999/11/22 02:53:46 morgan Exp $
+ * $Id: pwdb_chkpwd.c,v 1.2 2000/11/19 23:54:04 agmorgan Exp $
  *
  * This program is designed to run setuid(root) or with sufficient
  * privilege to read all of the unix password databases. It is designed
@@ -13,12 +13,7 @@
  *
  */
 
-#define _BSD_SOURCE
-
-#ifdef linux
-# define _GNU_SOURCE
-# include <features.h>
-#endif
+#include <security/_pam_aconf.h>
 
 #include <stdarg.h>
 #include <stdio.h>
