@@ -46,6 +46,10 @@
 #include <endian.h>
 #endif
 
+#ifdef NEED_FSUID_H
+#include <sys/fsuid.h>
+#endif /* NEED_FSUID_H */
+
 #include <sys/types.h>
 #include <sys/uio.h>
 #include <string.h>
@@ -783,6 +787,12 @@ struct pam_module _pam_rhosts_auth_modstruct = {
 
 /*
  * $Log: pam_rhosts_auth.c,v $
+ * Revision 1.1.1.1  2000/06/20 22:11:56  agmorgan
+ * Imported 0.72 Linux-PAM sources
+ *
+ * Revision 1.4  1999/11/08 05:46:58  morgan
+ * fixes for .71
+ *
  * Revision 1.3  1999/10/09 05:12:49  morgan
  * added hosts_equiv_rootok support
  *
