@@ -1,7 +1,7 @@
 /*
  * pam_tally.c
  * 
- * $Id: pam_tally.c,v 1.6 1999/10/09 05:15:17 morgan Exp $
+ * $Id: pam_tally.c,v 1.2 2000/11/19 23:54:05 agmorgan Exp $
  */
 
 
@@ -11,10 +11,7 @@
  * Stuff stolen from pam_rootok and pam_listfile
  */
 
-#ifdef linux
-# define _GNU_SOURCE
-# include <features.h>
-#endif
+#include <security/_pam_aconf.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -22,6 +19,7 @@
 #include <stdarg.h>
 #include <syslog.h>
 #include <pwd.h>
+#include <time.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -69,7 +67,9 @@ enum TALLY_RESET {
 #endif
 
 static struct faillog faillog;
+#ifndef MAIN
 static time_t fail_time;
+#endif /* ndef MAIN */
 
 /*---------------------------------------------------------------------*/
 
