@@ -1,4 +1,6 @@
 /*
+ * $Id: pam_unix_sess.c,v 1.2 2000/11/19 23:54:05 agmorgan Exp $
+ *
  * Copyright Alexander O. Yuriev, 1996.  All rights reserved.
  * Copyright Jan Rkorajski, 1999.  All rights reserved.
  *
@@ -34,10 +36,7 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifdef linux
-#define _GNU_SOURCE
-#include <features.h>
-#endif
+#include <security/_pam_aconf.h>
 
 #include <stdio.h>
 #include <stdlib.h>
