@@ -1,5 +1,5 @@
 /* 
- * $Id: support.c,v 1.3 1999/10/09 05:07:32 morgan Exp $
+ * $Id: support.c,v 1.4 2000/11/25 04:40:55 agmorgan Exp $
  *
  * Copyright information at end of file.
  */
@@ -398,7 +398,6 @@ static int _unix_run_helper_binary(pam_handle_t *pamh, const char *passwd, unsig
 	exit(PAM_AUTHINFO_UNAVAIL);
     } else if (child > 0) {
 	/* wait for child */
-	close(fds[0]);
 	/* if the stored password is NULL */
 	if (off(UNIX__NONULL, ctrl)) {	/* this means we've succeeded */
 	    write(fds[1], "nullok\0\0", 8);
@@ -411,6 +410,7 @@ static int _unix_run_helper_binary(pam_handle_t *pamh, const char *passwd, unsig
 	} else {
 	    write(fds[1], "", 1);                        /* blank password */
 	}
+	close(fds[0]);       /* close here to avoid possible SIGPIPE above */
 	close(fds[1]);
 	(void) waitpid(child, &retval, 0);  /* wait for helper to complete */
 	retval = (retval == 0) ? PAM_SUCCESS:PAM_AUTH_ERR;
@@ -525,6 +525,8 @@ int _unix_verify_password(pam_handle_t * pamh, const char *name
 				D(("user has empty password - access denied"));
 				retval = PAM_AUTH_ERR;
 			}
+		} else if (!p) {
+				retval = PAM_AUTH_ERR;
 		} else {
 			if (!strncmp(salt, "$1$", 3)) {
 				pp = Goodcrypt_md5(p, salt);
